BlendMode enum
A blend mode.
Values
- colorBurn → const BlendMode
-
ColorBurn mode.
- darken → const BlendMode
-
Darken mode.
- hardLight → const BlendMode
-
HardLight mode.
- lighten → const BlendMode
-
Lighten mode.
- multiply → const BlendMode
-
Multiply mode.
- normal → const BlendMode
-
Normal mode.
- overlay → const BlendMode
-
Overlay mode.
- screen → const BlendMode
-
Screen mode.
- softLight → const BlendMode
-
SoftLight mode.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited