categories property

List<VideoClipCategory>? categories
final

Defines all available video clips in the video clip library. Each video clip must be assigned to a category.

If this array is null the defaults are used. If this array is empty the video clip library won't be shown when the user taps the add button in the composition menu instead the device's media library will be shown directly when personalVideoClips is enabled. If personalVideoClips is disabled in this case the add button in the composition menu won't be shown at all.

// Defaults to:
[]

Implementation

final List<VideoClipCategory>? categories;