CropRatio class
A crop aspect ratio.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
The height of the ratio.
final
- name → String?
-
A displayable name for the item which is also used for accessibility.
If
nullthe name is automatically generated from thewidthandheightvalues and the name will always be overwritten by this auto-generated name if the user toggles the aspect whentoggleableis enabled.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toggleable → bool?
-
If enabled the
widthandheightof a ratio can be toggled in the UI.final - width → double
-
The width of the ratio.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited