ExistingTheme enum
An existing theme that is shipped with the SDK.
Values
- dark → const ExistingTheme
-
The dark theme.
- light → const ExistingTheme
-
The light theme.
- dynamic → const ExistingTheme
-
A theme that switches dynamically between the light and the dark theme based on the user interface state of the device. This ExistingTheme is only supported on iOS.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ExistingTheme> - A constant List of the values in this enum, in order of their declaration.