TextDesignOptions class
Configuration options for Tool.textDesign.
Constructors
-
TextDesignOptions({List<
TextDesignCanvasAction> ? canvasActions, ColorPalette? colors, List<TextDesign> ? items}) - Creates new TextDesignOptions.
Properties
-
canvasActions
→ List<
TextDesignCanvasAction> ? -
The available TextDesignCanvasAction when a text design
is selected.
final
- colors → ColorPalette?
-
The available colors to choose from.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
TextDesign> ? -
The available TextDesigns.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited