actions property

List<TextAction>? actions
final

Defines all allowed actions for the text tool menu. Only buttons for allowed actions are visible and shown in the given order.

// Defaults to:
[TextAction.font, TextAction.color,
TextAction.backgroundColor, TextAction.alignment]

Implementation

final List<TextAction>? actions;