ThemeOptions class

Configuration options for the Theme of the editor.

Creating custom themes and modifying exsiting themes for Android requires to create the corresponding styles in XML files first. For instructions, please refer to our documentation: https://img.ly/docs/pesdk/android/customization/themes/

Constructors

ThemeOptions(Theme theme)
Creates a new instance. The given theme will be used to style the editor.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme Theme
The active theme that should be used to style the user interface.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited