Tool enum
An image and/or video editing tool.
Values
- adjustment → const Tool
-
A tool to apply image adjustments.
- audio → const Tool
-
A tool to edit the audio track of videos.
- brush → const Tool
-
A tool to add drawings.
- composition → const Tool
-
A tool to compose a video from multiple video clips and to trim the timeline of the composition and the individual clips.
- filter → const Tool
-
A tool to apply an image filter effect.
- focus → const Tool
-
A tool to add blur.
- frame → const Tool
-
A tool to add a frame.
- overlay → const Tool
-
A tool to add an overlay..
- sticker → const Tool
-
A tool to add stickers.
- text → const Tool
-
A tool to add texts.
- textDesign → const Tool
-
A tool to add text designs.
- transform → const Tool
-
A tool to apply an transformation, such as cropping or rotation.
- trim → const Tool
-
A tool to trim the timeline of videos.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited