ThemeOptions class
Configuration options for the Theme of the editor.
Creating custom themes and modifying exsiting themes for Android requires to create the corresponding styles in XML files first. For instructions, please refer to our documentation: https://img.ly/docs/pesdk/android/customization/themes/
Constructors
- ThemeOptions(Theme theme)
-
Creates a new instance.
The given
themewill be used to style the editor.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited